<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr" sourcelanguage="en">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Copy</source>
        <translation>Copier</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Rename</source>
        <translation>Renomer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Move</source>
        <translation>Déplacer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Edit</source>
        <translation>Editer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Share</source>
        <translation>Partager</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Compress</source>
        <translation>Compresser</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Documents</source>
        <translation>Documents</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Images</source>
        <translation>Images</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Camera</source>
        <translation>Photos</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Sounds</source>
        <translation>Sons</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Videos</source>
        <translation>Videos</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Added to Clipboard</source>
        <translation>Ajouter au presse papier</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>ERROR: Nothing selected to paste</source>
        <translation>ERREUR: Rien n&apos;a été selectionner</translation>
    </message>
    <message>
        <location filename="../error.cpp" line="10"/>
        <source>Not enough space to proceed.</source>
        <translation>Il n&apos;y a plus de place pour continuer.</translation>
    </message>
    <message>
        <location filename="../error.cpp" line="10"/>
        <source>You don&apos;t have permissions to proceed.</source>
        <translation>Vous n&apos;avez pas les droits pour continuer.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>About</source>
        <translation>A propos de</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Broken Symlink!</source>
        <translation>lien symbolique cassé!</translation>
    </message>
</context>
<context>
    <name>BookWindow</name>
    <message>
        <location filename="../bookwindow.cpp" line="10"/>
        <source>Bookmarks</source>
        <translation>Favoris</translation>
    </message>
</context>
<context>
    <name>Home</name>
    <message>
        <location filename="../home.cpp" line="10"/>
        <source>Home folder</source>
        <translation>Dossier personnel</translation>
    </message>
    <message>
        <location filename="../home.cpp" line="10"/>
        <source>Compress destination</source>
        <translation>Compresser destination</translation>
    </message>
    <message>
        <location filename="../home.cpp" line="10"/>
        <source>Extract destination</source>
        <translation>Extraire vers</translation>
    </message>
</context>
<context>
    <name>Clipboard</name>
    <message>
        <location filename="../clipboard.cpp" line="10"/>
        <source>Clipboard</source>
        <translation>Presse-papiers</translation>
    </message>
</context>
<context>
    <name>Bookmarks</name>
    <message>
        <location filename="../bookmarks.cpp" line="10"/>
        <source>Bookmarks</source>
        <translation>Favoris</translation>
    </message>
    <message>
        <location filename="../bookmarks.cpp" line="10"/>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
</context>
<context>
    <name>ToolsDialog</name>
    <message>
        <location filename="../toolsdialog.cpp" line="10"/>
        <source>Tools</source>
        <translation>Outils</translation>
    </message>
    <message>
        <location filename="../toolsdialog.cpp" line="10"/>
        <source>Add to Bookmarks</source>
        <translation>Ajouter aux favoris</translation>
    </message>
    <message>
        <location filename="../toolsdialog.cpp" line="10"/>
        <source>Create new folder</source>
        <translation>Créer un nouveau dossier</translation>
    </message>
    <message>
        <location filename="../toolsdialog.cpp" line="10"/>
        <source>Create new document</source>
        <translation>Créer un nouveau document</translation>
    </message>
    <message>
        <location filename="../toolsdialog.cpp" line="10"/>
        <source>Open terminal here</source>
        <translation>Ouvrir un terminal ici</translation>
    </message>
    <message>
        <location filename="../toolsdialog.cpp" line="10"/>
        <source>Sort</source>
        <translation>Trier</translation>
    </message>
</context>
<context>
    <name>Share</name>
    <message>
        <location filename="../share.cpp" line="10"/>
        <source>Share</source>
        <translation>Partager</translation>
    </message>
    <message>
        <location filename="../share.cpp" line="10"/>
        <source>Send via bluetooth</source>
        <translation>Envoyer par bluetooth</translation>
    </message>
    <message>
        <location filename="../share.cpp" line="10"/>
        <source>Send via e-mail</source>
        <translation>Envoyer par email</translation>
    </message>
</context>
<context>
    <name>QtCopyDialog</name>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>%1 of %2 completed</source>
        <translation>%1 de %2 terminé</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Warning</source>
        <translation>Attention</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Copy Warning</source>
        <translation>Attention</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Source doesn&apos;t exist.</source>
        <translation>La source n&apos;existe pas.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>No enough space for copy the file.</source>
        <translation>Pas assez d&apos;espace pour copier le fichier.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Source file is a directory. Omitting source directory.</source>
        <translation>Le fichier source est un répertoire. Oublie du dossier source.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Source directory is a file. Omitting source file.</source>
        <translation>Le dossier source est un fichier. Oublie du fichier source.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Path to destination does not exist.</source>
        <translation>Le chemin de destination n&apos;existe pas.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Cannot create destination directory.</source>
        <translation>Impossible de créer le répertoire de destination.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Cannot open source file. Please check permissions.</source>
        <translation>Impossible d&apos;ouvrir le fichier source. S&apos;il vous plaît vérifier les permissions.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Cannot open destination file. Please check permissions.</source>
        <translation>Impossible d&apos;ouvrir le fichier de destination. S&apos;il vous plaît vérifier les permissions.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Force: Cannot remove destination file.</source>
        <translation>Impossible de supprimer le fichier de destination.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Cannot create symbolic link targeting to source.</source>
        <translation>Impossible de créer un lien symbolique vers la source.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Cannot read source file.</source>
        <translation>Impossible de lire le fichier source.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Cannot write destination file.</source>
        <translation>Impossible d&apos;écrire le fichier de destination.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Cannot remove source.</source>
        <translation>Impossible de supprimer la source.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>100% of %1 (Done)</source>
        <translation>100% de %1 (Terminé)</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Copying...</source>
        <translation>Copie en cours...</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>%1% of %2 (%3)</source>
        <translation>%1% de %2 (%3)</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Done</source>
        <translation>Terminé</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Source</source>
        <translation>Source</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Destination</source>
        <translation>Destination</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
</context>
<context>
    <name>QtOverwriteDialog</name>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Copy Warning</source>
        <translation>Attention</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Source</source>
        <translation>Source</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Destination</source>
        <translation>Destination</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Skip</source>
        <translation>Passer</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Overwrite</source>
        <translation>Écraser</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Destination already exists.</source>
        <translation>La destination existe déjà.</translation>
    </message>
</context>
<context>
    <name>DeleteDialog</name>
    <message>
        <location filename="../deletedialog.cpp" line="10"/>
        <source>Preparing to delete %1 files</source>
        <translation>Préparation à la suppression de %1 files</translation>
    </message>
    <message>
        <location filename="../deletedialog.cpp" line="10"/>
        <source>Deleting %1</source>
        <translation>Suppression %1</translation>
    </message>
    <message>
        <location filename="../deletedialog.cpp" line="10"/>
        <source>Error deleting %1</source>
        <translation>Erreur de suppression de %1</translation>
    </message>
    <message>
        <location filename="../deletedialog.cpp" line="10"/>
        <source>Delete Finished Ok</source>
        <translation>Suppression terminée avec succès</translation>
    </message>
    <message>
        <location filename="../deletedialog.cpp" line="10"/>
        <source>Abort</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../deletedialog.cpp" line="10"/>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <location filename="../deletedialog.cpp" line="10"/>
        <source>Deleting files</source>
        <translation>Suppression de fichiers</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Settings</source>
        <translation>Paramètres</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Apply</source>
        <translation>Appliquer</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Home folder</source>
        <translation>Dossier personnel</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Icons Style</source>
        <translation>style d&apos;icônes</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Text Editor</source>
        <translation>Editeur de texte</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Enable root access (restart needed)</source>
        <translation>Activer l&apos;accès root (redémarrage nécessaire)</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Show hidden files and folders</source>
        <translation>Afficher les fichiers et dossiers cachés</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Show thumbnails for images</source>
        <translation>Afficher les aperçus pour les images</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Show details for files</source>
        <translation>Voir les détails des fichiers</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Delete items from clipboard on Paste</source>
        <translation>Supprimer des éléments du Presse-papiers</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Enable multiselection</source>
        <translation>Activer la multiselection</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Auto select items in clipboard</source>
        <translation>Sélection automatique des éléments du Presse-papiers</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Orientation</source>
        <translation>Orientation</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Automatic</source>
        <translation>Automatique</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Portrait</source>
        <translation>Portrait</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Landscape</source>
        <translation>Paysage</translation>
    </message>
</context>
<context>
    <name>NewFolder</name>
    <message>
        <location filename="../newfolder.cpp" line="10"/>
        <source>Create folder</source>
        <translation>Créer un dossier</translation>
    </message>
    <message>
        <location filename="../newfolder.cpp" line="10"/>
        <source>Enter new folder name</source>
        <translation>Entrez le nom du nouveau dossier</translation>
    </message>
    <message>
        <location filename="../newfolder.cpp" line="10"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../newfolder.cpp" line="10"/>
        <source>Accept</source>
        <translation>Accepter</translation>
    </message>
    <message>
        <location filename="../newfolder.cpp" line="10"/>
        <source>Cannot create folder. Try another name.</source>
        <translation>Impossible de créer le dossier. Essayez un autre nom.</translation>
    </message>
</context>
<context>
    <name>QtOtherDialog</name>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Retry</source>
        <translation>Réessayer</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Skip</source>
        <translation>Passer</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Source</source>
        <translation>Source</translation>
    </message>
    <message>
        <location filename="../newfolder.cpp" line="10"/>
        <source>Destination</source>
        <translation>Destination</translation>
    </message>
</context>
<context>
    <name>Rename</name>
    <message>
        <location filename="../rename.cpp" line="10"/>
        <source>Renaming</source>
        <translation>Renommer</translation>
    </message>
    <message>
        <location filename="../rename.cpp" line="10"/>
        <source>Enter new name</source>
        <translation>Entrez le nouveau nom</translation>
    </message>
    <message>
        <location filename="../rename.cpp" line="10"/>
        <source>Accept</source>
        <translation>Accepter</translation>
    </message>
    <message>
        <location filename="../rename.cpp" line="10"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../rename.cpp" line="10"/>
        <source>Cannot rename. Try another name.</source>
        <translation>Impossible de renommer. Essayez un autre nom.</translation>
    </message>
</context>
<context>
    <name>AskDialog</name>
    <message>
        <location filename="../askdialog.cpp" line="10"/>
        <source>Deleting</source>
        <translation>Suppression</translation>
    </message>
    <message>
        <location filename="../askdialog.cpp" line="10"/>
        <source>Are you sure you want to delete %1?</source>
        <translation>Etes-vous sûr de vouloir supprimer %1?</translation>
    </message>
    <message>
        <location filename="../askdialog.cpp" line="10"/>
        <source>Are you sure you want to delete selected files?</source>
        <translation>Etes-vous sûr de vouloir supprimer les fichiers sélectionnés?</translation>
    </message>
    <message>
        <location filename="../askdialog.cpp" line="10"/>
        <source>Yes</source>
        <translation>Oui</translation>
    </message>
    <message>
        <location filename="../askdialog.cpp" line="10"/>
        <source>No</source>
        <translation>Non</translation>
    </message>
</context>
<context>
    <name>Sort</name>
    <message>
        <location filename="../sort.cpp" line="10"/>
        <source>Sort</source>
        <translation>Trier</translation>
    </message>
    <message>
        <location filename="../sort.cpp" line="10"/>
        <source>Ascending</source>
        <translation>Ascendant</translation>
    </message>
    <message>
        <location filename="../sort.cpp" line="10"/>
        <source>Descending</source>
        <translation>Descendant</translation>
    </message>
    <message>
        <location filename="../sort.cpp" line="10"/>
        <source>Name (A-Z)</source>
        <translation>Nom (A-Z)</translation>
    </message>
    <message>
        <location filename="../sort.cpp" line="10"/>
        <source>Name (Z-A)</source>
        <translation>Nom (Z-A)</translation>
    </message>
    <message>
        <location filename="../sort.cpp" line="10"/>
        <source>Date (olders first)</source>
        <translation>Date (plus anciens en premier)</translation>
    </message>
    <message>
        <location filename="../sort.cpp" line="10"/>
        <source>Date (recents first)</source>
        <translation>Date (plus récents en premier)</translation>
    </message>
    <message>
        <location filename="../sort.cpp" line="10"/>
        <source>Size (smallers first)</source>
        <translation>Taille (plus petits d&apos;abord)</translation>
    </message>
    <message>
        <location filename="../sort.cpp" line="10"/>
        <source>Size (biggers first)</source>
        <translation>Taille (plus gros d&apos;abord)</translation>
    </message>
</context>
<context>
    <name>NewDoc</name>
    <message>
        <location filename="../newdoc.cpp" line="10"/>
        <source>New document</source>
        <translation>Nouveau document</translation>
    </message>
    <message>
        <location filename="../newdoc.cpp" line="10"/>
        <source>Create</source>
        <translation>Créer</translation>
    </message>
    <message>
        <location filename="../newdoc.cpp" line="10"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../newdoc.cpp" line="10"/>
        <source>Enter name for new document</source>
        <translation>Entrez le nom de nouveau document</translation>
    </message>
    <message>
        <location filename="../newdoc.cpp" line="10"/>
        <source>Enter a valid file name</source>
        <translation>Entrez un nom de fichier valide</translation>
    </message>
    <message>
        <location filename="../newdoc.cpp" line="10"/>
        <source>The file already exists. Try another name</source>
        <translation>Le dossier existe déjà. Essayez un autre nom</translation>
    </message>
    <message>
        <location filename="../newdoc.cpp" line="10"/>
        <source>Cannot create the file. Check permissions</source>
        <translation>Impossible de créer le fichier. Vérifiez les autorisations</translation>
    </message>
</context>
<context>
    <name>Error</name>
    <message>
        <location filename="../error.cpp" line="10"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../error.cpp" line="10"/>
        <source>Accept</source>
        <translation>Accepter</translation>
    </message>
</context>
<context>
    <name>CompressDlg</name>
    <message>
        <location filename="../compressdlg.cpp" line="10"/>
        <source>Compress</source>
        <translation>Compresser</translation>
    </message>
    <message>
        <location filename="../compressdlg.cpp" line="10"/>
        <source>File name</source>
        <translation>Nom du fichier</translation>
    </message>
    <message>
        <location filename="../compressdlg.cpp" line="10"/>
        <source>Compression</source>
        <translation>Compression</translation>
    </message>
    <message>
        <location filename="../compressdlg.cpp" line="10"/>
        <source>Destination folder</source>
        <translation>Le dossier de destination</translation>
    </message>
    <message>
        <location filename="../compressdlg.cpp" line="10"/>
        <source>Accept</source>
        <translation>Accepter</translation>
    </message>
    <message>
        <location filename="../compressdlg.cpp" line="10"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../compressdlg.cpp" line="10"/>
        <source>The file already exists. Try another name.</source>
        <translation>Le dossier existe déjà. Essayez un autre nom.</translation>
    </message>
    <message>
        <location filename="../compressdlg.cpp" line="10"/>
        <source>Not enough space to proceed.</source>
        <translation>Pas assez d&apos;espace pour continuer.</translation>
    </message>
    <message>
        <location filename="../compressdlg.cpp" line="10"/>
        <source>You don&apos;t have permissions to proceed.</source>
        <translation>Vous ne disposez pas des autorisations pour continuer.</translation>
    </message>
</context>
<context>
    <name>Compress</name>
    <message>
        <location filename="../compress.cpp" line="10"/>
        <source>Compressing</source>
        <translation>Compression en cours</translation>
    </message>
    <message>
        <location filename="../compress.cpp" line="10"/>
        <source>Adding %1...</source>
        <translation>Ajout de %1...</translation>
    </message>
    <message>
        <location filename="../compress.cpp" line="10"/>
        <source>Operation finished.</source>
        <translation>Opération terminée.</translation>
    </message>
    <message>
        <location filename="../compress.cpp" line="10"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../compress.cpp" line="10"/>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
</context>
<context>
    <name>Unzip</name>
    <message>
        <location filename="../unzip.cpp" line="10"/>
        <source>Extract files</source>
        <translation>Extraire les fichiers</translation>
    </message>
    <message>
        <location filename="../unzip.cpp" line="10"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../unzip.cpp" line="10"/>
        <source>Not enough space to proceed.</source>
        <translation>Pas assez d&apos;espace pour continuer.</translation>
    </message>
    <message>
        <location filename="../unzip.cpp" line="10"/>
        <source>You don&apos;t have permissions to proceed.</source>
        <translation>Vous ne disposez pas des autorisations pour continuer.</translation>
    </message>
</context>
<context>
    <name>UnzipDlg</name>
    <message>
        <location filename="../unzipdlg.cpp" line="10"/>
        <source>Extract</source>
        <translation>Extraire</translation>
    </message>
    <message>
        <location filename="../unzipdlg.cpp" line="10"/>
        <source>Destination folder</source>
        <translation>Le dossier de destination</translation>
    </message>
    <message>
        <location filename="../unzipdlg.cpp" line="10"/>
        <source>Keep existing files</source>
        <translation>Conserver les fichiers existants</translation>
    </message>
    <message>
        <location filename="../unzipdlg.cpp" line="10"/>
        <source>Accept</source>
        <translation>Accepter</translation>
    </message>
    <message>
        <location filename="../unzipdlg.cpp" line="10"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>Extract</name>
    <message>
        <location filename="../extract.cpp" line="10"/>
        <source>Extracting</source>
        <translation>Extraction en cours</translation>
    </message>
    <message>
        <location filename="../extract.cpp" line="10"/>
        <source>Extracting %1...</source>
        <translation>Extraction de %1...</translation>
    </message>
    <message>
        <location filename="../extract.cpp" line="10"/>
        <source>Operation finished.</source>
        <translation>Opération terminée.</translation>
    </message>
    <message>
        <location filename="../extract.cpp" line="10"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../extract.cpp" line="10"/>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
</context>
<context>
    <name>About</name>
    <message>
        <location filename="../about.cpp" line="10"/>
        <source>About FileBox</source>
        <translation>A propos de FileBox</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="10"/>
        <source>File Manager for Maemo 5</source>
        <translation>Gestionnaire de fichiers pour Maemo 5</translation>
    </message>
</context>
</TS>
